package tp3.atmsystem;

public class Main {
    public static void main(String[] args) {
        Bank bank = new Bank();
        ATMSystem atmSystem = new ATMSystem(bank);
        bank.addAccount("1000", 123456, 1234, 500.00);  // (accountNumber, cardNumber, pin, initialBalance)

        // Tests
        System.out.println("=== Test All Good ===");
        testAllGood(atmSystem);

        System.out.println("\n=== Test Invalid Card ===");
        testInvalidCard(atmSystem);

        System.out.println("\n=== Test Invalid PIN ===");
        testInvalidPin(atmSystem);

        System.out.println("\n=== Test Insufficient Balance ===");
        testInsufficientBalance(atmSystem);
    }

    // Test : All good
    public static void testAllGood(ATMSystem atmSystem) {
        int cardNumber = 123456;
        int enteredPin = 1234;
        double withdrawalAmount = 200.00;

        System.out.println("CardHolder inserts card : " + cardNumber);

        if (atmSystem.validateCard(cardNumber)) {
            System.out.println("Valid card");
        } else {
            System.out.println("Invalid card.");
            return;
        }

        System.out.println("CardHolder enters PIN : " + enteredPin);
        if (atmSystem.authenticateUser(cardNumber, enteredPin)) {
            System.out.println("PIN is correct.");
        } else {
            System.out.println("Incorrect PIN.");
            return;
        }

        System.out.println("CardHolder asks for a withdrawal of : $" + withdrawalAmount);
        atmSystem.withdraw(cardNumber, withdrawalAmount);
    }

    // Test : invalid card
    public static void testInvalidCard(ATMSystem atmSystem) {
        int cardNumber = 0;  // Invalid card
        
        System.out.println("CardHolder inserts card : " + cardNumber);

        if (atmSystem.validateCard(cardNumber)) {
            System.out.println("Valid card");
        } else {
            System.out.println("Invalid card.");
        }
    }

    // Test : invalid PIN
    public static void testInvalidPin(ATMSystem atmSystem) {
        int cardNumber = 123456;
        int enteredPin = 9999;  // wrong PIN
        
        System.out.println("CardHolder inserts card : " + cardNumber);

        if (atmSystem.validateCard(cardNumber)) {
            System.out.println("Valid card");
        } else {
            System.out.println("Invalid card.");
            return;
        }

        System.out.println("CardHolder enters PIN : " + enteredPin);
        if (atmSystem.authenticateUser(cardNumber, enteredPin)) {
            System.out.println("PIN is correct.");
        } else {
            System.out.println("Incorrect PIN.");
        }
    }

    // Test : Balance too low
    public static void testInsufficientBalance(ATMSystem atmSystem) {
        int cardNumber = 123456;
        int enteredPin = 1234;
        double withdrawalAmount = 1000.00;  // amount > balance

        System.out.println("CardHolder inserts card : " + cardNumber);

        if (atmSystem.validateCard(cardNumber)) {
            System.out.println("Valid card");
        } else {
            System.out.println("Invalid card.");
            return;
        }

        System.out.println("CardHolder enters PIN : " + enteredPin);
        if (atmSystem.authenticateUser(cardNumber, enteredPin)) {
            System.out.println("PIN is correct.");
        } else {
            System.out.println("Incorrect PIN.");
            return;
        }

        System.out.println("CardHolder asks for a withdrawal of : $" + withdrawalAmount);
        atmSystem.withdraw(cardNumber, withdrawalAmount);
    }
}
